==> cairo-compmgr-0.2.93.tar.gz: cairo-compmgr-0.2.93/lib/ccm-timeout-pool.h <==
/*
 * Authored By Matthew Allum  <mallum@openedhand.com>
 *
 * Copyright (C) 2006 OpenedHand
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * CCMTimeoutPool: pool of timeout functions using the same slice of
 *                     the GLib main loop
 *
 * Author: Emmanuele Bassi <ebassi@openedhand.com>
 *
 * Based on similar code by Tristan van Berkom
 * Based on clutter_timeout_pool
 */

#ifndef __CCM_TIMEOUT_POOL_H__
#define __CCM_TIMEOUT_POOL_H__

#include <glib.h>

G_BEGIN_DECLS

typedef struct _CCMTimeoutPool    CCMTimeoutPool;

CCMTimeoutPool*         ccm_timeout_pool_new    (gint                priority);
guint                   ccm_timeout_pool_add    (CCMTimeoutPool *pool,
                                                 guint               interval,
                                                 GSourceFunc         func,
                                                 gpointer            data,
                                                 GDestroyNotify      notify);
void                    ccm_timeout_pool_remove (CCMTimeoutPool *pool,
                                                 guint               id);

G_END_DECLS

#endif /* __CCM_TIMEOUT_POOL_H__ */

==> cairo-compmgr-0.3.0.tar.gz: cairo-compmgr-0.3.0/lib/ccm-timeout-pool.h <==
/*
 * Authored By Matthew Allum  <mallum@openedhand.com>
 *
 * Copyright (C) 2006 OpenedHand
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * CCMTimeoutPool: pool of timeout functions using the same slice of
 *                     the GLib main loop
 *
 * Author: Emmanuele Bassi <ebassi@openedhand.com>
 *
 * Based on similar code by Tristan van Berkom
 * Based on clutter_timeout_pool
 */

#ifndef __CCM_TIMEOUT_POOL_H__
#define __CCM_TIMEOUT_POOL_H__

#include <glib.h>

G_BEGIN_DECLS typedef struct _CCMTimeoutPool CCMTimeoutPool;

CCMTimeoutPool *ccm_timeout_pool_new (gint priority);
guint ccm_timeout_pool_add (CCMTimeoutPool * pool, guint interval,
                            GSourceFunc func, gpointer data,
                            GDestroyNotify notify);
void ccm_timeout_pool_remove (CCMTimeoutPool * pool, guint id);
void ccm_timeout_set_master (CCMTimeoutPool * pool, guint id);

G_END_DECLS
#endif                          /* __CCM_TIMEOUT_POOL_H__ */
